@@ -1,6 +1,7 @@
 
 
 #include <QMainWindow>
+#include <QHash>
 
 class QMaemo5ValueButton;
 class QRadioButton;
@@ -24,6 +25,8 @@ private:
 	QRadioButton *m_rbsilent; 
         QRadioButton *m_rboffline;
         QRadioButton *m_rbonline;
+        QHash<QString,QRadioButton *> qhcb;
+
 	
 };
 
