@@ -11,7 +11,9 @@ public:
 public slots:
 	void AddAlarm();
         void DelAlarm( const QModelIndex & index );
+        void DelAlarm();
         void refreshList();
+        void contextMenu(const QPoint & pt);
 
 private:
         QListView *m_view;
